:mod:`uint` --- UInt160 and UInt256 data structures
===================================================

The UInt classes are bytearray like classes heavily used through the NEO system. See :ref:`library-complextypes`.

.. automodule:: neo3.core.types.uint
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members: